%define name fftw
%define version 2.1.3
%define release 7mdk

Name: %{name}
Summary: Fast fourier transform library
Version: %{version}
Release: %{release}
Copyright: GPL
Icon: fftw-logo-thumb.gif
Group: Development/C
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-buildroot
Source: %{name}-%{version}.tar.bz2
Patch0: %{name}-%{version}-pentium.patch.bz2
URL: http://www.fftw.org
Provides: libfftw
Obsoletes: libfftw
BuildRequires: /sbin/ldconfig, /usr/bin/f77
Requires: /sbin/ldconfig


%description
FFTW is a collection of fast C routines for computing the Discrete Fourier
Transform in one or more dimensions.  It includes complex, real, and
parallel transforms, and can handle arbitrary array sizes efficiently.
This RPM package includes both the double- and single-precision FFTW
uniprocessor and threads libraries.  (The single-precision files have
an "s" prefix.)

%package devel
Summary: headers, libraries, & docs for FFTW fast fourier transform library
Group: Development/C
Prefix: %{_prefix}
Requires: %{name} = %{version}-%{release}
Obsoletes: libfftw-devel

%description devel
This package contains the additional header files, documentation, and
libraries you need to develop programs using the FFTW fast fourier
transform library.

%prep
rm -rf $RPM_BUILD_ROOT

# We will be compiling two copies of FFTW, one for double precision and
# one for single precision.  During the build process, these copies
# will be stored in fftw-%{version}/double and fftw-%{version}/single

# Unpack the tar archive, first (-c) creating a fftw-%{version}
# directory and then unpacking in there.

%setup -c
# Now, rename the unpacked FFTW directory to "double":
mv ${RPM_PACKAGE_NAME}-${RPM_PACKAGE_VERSION} double
# Apply patch to enable pentium optimizations
cd double
%patch0 -p1
cd ..
# Last, make a copy of this directory in "single":
cp -r double single

%build

# Configure and build the double and single precision versions.
# Notes:
#  (1) We install into ${RPM_BUILD_ROOT}, which is set either
#      by the BuildRoot option above or by --buildroot at build-time.
#      This allows you to build the RPM without blowing away your existing
#      FFTW installation, and even without being root.
#  (2) The double-precision version is installed with the normal library
#      names, while the single-precision version is installed with an "s"
#      prefix.

cd double
%ifarch %{ix86}
    %configure --enable-shared --enable-threads --infodir=$RPM_BUILD_ROOT%{_infodir} --enable-i386-hacks
%else
    %configure --enable-shared --enable-threads --infodir=$RPM_BUILD_ROOT%{_infodir}
%endif
%make

cd ../single
%ifarch %{ix86}
    %configure --enable-shared --enable-threads --infodir=$RPM_BUILD_ROOT%{_infodir} --enable-i386-hacks --enable-float --enable-type-prefix 
%else
    %configure --enable-shared --enable-threads --infodir=$RPM_BUILD_ROOT%{_infodir} --enable-float --enable-type-prefix
%endif
%make

%install
cd double
%makeinstall
cd ../single
%makeinstall

# copy doc files where RPM will find them
# put the HTML stuff in a sperate dir, so it appears nicely in the docdir
mkdir -p ../html
cp doc/*html doc/*gif ../html
# remove HTML files from doc so that they don't appear double
rm -f doc/*html doc/*gif

# place the doc directory in a "findable" location
mkdir -p ../doc
cp -a doc/* ../doc

# the FAQ directory is also "nice" to have
mkdir -p ../FAQ
cp -a FAQ/* ../FAQ

# do the same to the other %doc files
cp AUTHORS ChangeLog NEWS README* TODO ..

%clean

rm -rf ${RPM_BUILD_ROOT}

%post
# Warn the user fix a broken /etc/ld.so.conf manually:
if test -z `grep ${RPM_INSTALL_PREFIX}/lib /etc/ld.so.conf`; then
     echo "warning: ${RPM_INSTALL_PREFIX}/lib is not in /etc/ld.so.conf" 1>&2
     echo "         You should add it and then run ldconfig." 1>&2
fi

# run ldconfig to update the runtime linker database with the new libraries
# (make sure /sbin is in the $PATH)
PATH="/sbin:$PATH" ldconfig

%post devel
%_install_info %{_infodir}/*.bz2


%preun devel
%_remove_install_info %{_infodir}/*.bz2

%postun
# after uninstall, run ldconfig to remove the libs from the linker database
PATH="/sbin:$PATH" ldconfig

%files
%defattr (-,root,root)
%doc html FAQ doc/*ps doc/*fig doc/*tex* AUTHORS ChangeLog NEWS README* TODO
%{_libdir}/%{_lib}*fftw*.so.2*

%files devel
%defattr (-,root,root)
%{_includedir}/*fftw*.h
%doc %{_infodir}/*
%{_libdir}/%{_lib}*fftw*.a
%{_libdir}/%{_lib}*fftw*.la
%{_libdir}/%{_lib}*fftw*.so

%changelog
* Tue Jan 09 2001 Lenny Cartier <lenny@mandrakesoft.com> 2.1.3-7mdk
- rebuild

* Tue Aug 31 2000 Lenny Cartier <lenny@mandrakesoft.com> 2.1.3-6mdk
- add installinfo

* Wed Aug 30 2000 Alexander Skwar <ASkwar@DigitalProjects.com> 2.1.3-5mdk
- Actually used macros
- Added %doc files
- Shortened %files section of the SPEC file a lot
- Provide libfftw as eXtace requires it
- Obsolote libfftw package
- Optimized for Pentium builds per README.hacks

* Wed Aug 30 2000 Lenny Cartier <lenny@mandrakesoft.com> 2.1.3-4mdk
- BM
- macros

* Wed Apr 26 2000 Lenny Cartier <lenny@mandrakesoft.com> 2.1.3-3mdk
- fix group
- spec helper fixes

* Tue Jan 25 2000 Lenny Cartier <lenny@mandrakesoft.com>
- updated, installs in /usr instead of /usr/local by Dara Hazeghi
  <dara@pacbell.net>

* Thu Dec 16 1999 Lenny Cartier <lenny@mandrakesoft.com>
- new in contribs
- bz2 archive 
- add defattr
